// EmonTx V3 Direct Serial example
// AC-AC adapter must be used with this example (highly recomneded for more accurate Real Power calculations)
// Useful for direct connection to Raspberry Pi or computer via USB to UART cable 
// Forum thread: http://openenergymonitor.org/emon/node/3872
// serial print data modified for calibrating



// Tell emonLib this is the emonTx V3
// - don't read Vcc assume Vcc = 3.3V as is always the case on emonTx V3
// - eliminates bandgap error and need for calibration http://harizanov.com/2013/09/thoughts-on-avr-adc-accuracy/
#define emonTxV3
// Include Emon Library
#include "EmonLibDue.h"

// Create instances of circuits being monitored
EnergyMonitor circuit1, circuit2, circuit3, circuit4, circuit5, circuit6, circuit7, circuit8, circuit9, circuit10, circuit11;

unsigned long lastpost = 0;
const byte LEDpin = 13;                               // Arduino Due amber "L" LED
//const int nodeID = 12;                                // Identifies which node in the EmonHub config file the output of this sketch matches


void setup()
{
  pinMode(LEDpin, OUTPUT);
  digitalWrite(LEDpin, HIGH);
  analogReadResolution(ADC_BITS);
  Serial.begin(38400);
  //Serial.println("emonTx V3 Direct serial Example");

  /*for(int i=0; i<NSENSORS; i++)                       // Specify pins for voltage and current readings
    {
    Serial.println("Pins set up");
    circuiti.voltage(11, 268.97, 1.7);               //(ADC pin, Vcal Calibration, phase_shift) Voltage input is on A11
    circuiti.current(i, 90.9);                    //(ADC pin, Ical Calibration). Calibration value roughly = turns/burden in ohms
    }*/
  //The commented out loop above would work if the current calibration value is the same for each circuit.

  circuit1.voltage(0, 124.6, 1.7);                //(ADC pin, Vcal Calibration, phase_shift) Voltage input is on A0
  circuit1.current(1, 15);                      //(ADC pin, Ical Calibration). Calibration value roughly = turns/burden in ohms

  circuit2.voltage(0, 124.6, 1.7);
  circuit2.current(2, 15);

  circuit3.voltage(0, 124.6, 1.7);
  circuit3.current(3, 15);

  circuit4.voltage(0, 124.6, 1.7);
  circuit4.current(4, 15);

  circuit5.voltage(0, 124.6, 1.7);
  circuit5.current(5, 15);

  circuit6.voltage(0, 124.6, 1.7);
  circuit6.current(6, 15);

  circuit7.voltage(0, 124.6, 1.7);
  circuit7.current(7, 15);

  circuit8.voltage(0, 124.6, 1.7);
  circuit8.current(8, 20);

  circuit9.voltage(0, 124.6, 1.7);
  circuit9.current(9, 20);

  circuit10.voltage(0, 124.6, 1.7);
  circuit10.current(10, 50);

  circuit11.voltage(0, 124.6, 1.7);
  circuit11.current(11, 50);

  lastpost = 0;

  delay(2000);
  digitalWrite(LEDpin, LOW);
}

void loop()
{

  // A simple timer to fix the post rate to once every 10 seconds
  // Please dont post faster than once every 5 seconds to emoncms.org
  // Host your own local installation of emoncms for higher resolutions
  
  if ((millis()-lastpost)>=5000)
  {

    lastpost = millis();                         
    
    circuit1.calcVI(20,2000);                           //  .calcVI: Calculate all. No.of half wavelengths (crossings), time-out
    circuit2.calcVI(20,2000);
    circuit3.calcVI(20,2000);
    circuit4.calcVI(20,2000);
    circuit5.calcVI(20,2000);
    circuit6.calcVI(20,2000);
    circuit7.calcVI(20,2000);
    circuit8.calcVI(20,2000);
    circuit9.calcVI(20,2000);
    circuit10.calcVI(20,2000);
    circuit11.calcVI(20,2000);
    
    // Print to serial
 
  Serial.print(circuit1.Vrms); Serial.println(" V");
  
 
    Serial.print("CT1 (15A): ");
    Serial.print(circuit1.Irms); Serial.print(" A, ");
    Serial.print(circuit1.apparentPower); Serial.print(" VA, ");
    Serial.print(circuit1.realPower); Serial.println(" W.");

    Serial.print("CT2 (15A): ");
    Serial.print(circuit2.Irms); Serial.print(" A, ");
    Serial.print(circuit2.apparentPower); Serial.print(" VA, ");
    Serial.print(circuit2.realPower); Serial.println(" W.");
    
    Serial.print("CT3 (15A): ");
    Serial.print(circuit3.Irms); Serial.print(" A, ");
    Serial.print(circuit3.apparentPower); Serial.print(" VA, ");
    Serial.print(circuit3.realPower); Serial.println(" W.");

    Serial.print("CT4 (15A): ");
    Serial.print(circuit4.Irms); Serial.print(" A, ");
    Serial.print(circuit4.apparentPower); Serial.print(" VA, ");
    Serial.print(circuit4.realPower); Serial.println(" W.");

    Serial.print("CT5 (15A): ");
    Serial.print(circuit5.Irms); Serial.print(" A, ");
    Serial.print(circuit5.apparentPower); Serial.print(" VA, ");
    Serial.print(circuit5.realPower); Serial.println(" W.");

    Serial.print("CT6 (15A): ");
    Serial.print(circuit6.Irms); Serial.print(" A, ");
    Serial.print(circuit6.apparentPower); Serial.print(" VA, ");
    Serial.print(circuit6.realPower); Serial.println(" W.");

    Serial.print("CT7 (15A): ");
    Serial.print(circuit7.Irms); Serial.print(" A, ");
    Serial.print(circuit7.apparentPower); Serial.print(" VA, ");
    Serial.print(circuit7.realPower); Serial.println(" W.");

    Serial.print("CT8 (20A): ");
    Serial.print(circuit8.Irms); Serial.print(" A, ");
    Serial.print(circuit8.apparentPower); Serial.print(" VA, ");
    Serial.print(circuit8.realPower); Serial.println(" W.");

    Serial.print("CT9 (20A): ");
    Serial.print(circuit9.Irms); Serial.print(" A, ");
    Serial.print(circuit9.apparentPower); Serial.print(" VA, ");
    Serial.print(circuit9.realPower); Serial.println(" W.");

    Serial.print("CT10 (50A): ");
    Serial.print(circuit10.Irms); Serial.print(" A, ");
    Serial.print(circuit10.apparentPower); Serial.print(" VA, ");
    Serial.print(circuit10.realPower); Serial.println(" W.");

    Serial.print("CT11 (50A): ");
    Serial.print(circuit11.Irms); Serial.print(" A, ");
    Serial.print(circuit11.apparentPower); Serial.print(" VA, ");
    Serial.print(circuit11.realPower); Serial.println(" W.");

    digitalWrite(LEDpin,HIGH); 
    delay(200);
    digitalWrite(LEDpin,LOW); 
    
  }
}
